==> nopodofo-0.6.1.tgz: package/src/doc/Rect.h <==
/**
 * This file is part of the NoPoDoFo (R) project.
 * Copyright (c) 2017-2018
 * Authors: Cory Mickelson, et al.
 * 
 * NoPoDoFo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NoPoDoFo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NPDF_RECT_H
#define NPDF_RECT_H

#include <napi.h>
#include <podofo/podofo.h>

namespace NoPoDoFo {
class Rect : public Napi::ObjectWrap<Rect>
{
public:
  explicit Rect(const Napi::CallbackInfo& callbackInfo);
  static Napi::FunctionReference constructor;
  static void Initialize(Napi::Env& env, Napi::Object& target);

  void Intersect(const Napi::CallbackInfo&);
  Napi::Value GetWidth(const Napi::CallbackInfo&);
  void SetWidth(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetHeight(const Napi::CallbackInfo&);
  void SetHeight(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetBottom(const Napi::CallbackInfo&);
  void SetBottom(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetLeft(const Napi::CallbackInfo&);
  void SetLeft(const Napi::CallbackInfo&, const Napi::Value&);
  PoDoFo::PdfRect* GetRect() { return rect.get(); }

private:
  std::shared_ptr<PoDoFo::PdfRect> rect;
};
}
#endif // NPDF_RECT_H

==> nopodofo-0.6.3.tgz: package/src/doc/Rect.h <==
/**
 * This file is part of the NoPoDoFo (R) project.
 * Copyright (c) 2017-2018
 * Authors: Cory Mickelson, et al.
 *
 * NoPoDoFo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NoPoDoFo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef NPDF_RECT_H
#define NPDF_RECT_H

#include <napi.h>
#include <podofo/podofo.h>

namespace NoPoDoFo {
class Rect : public Napi::ObjectWrap<Rect>
{
public:
  explicit Rect(const Napi::CallbackInfo& callbackInfo);
  ~Rect();
  static Napi::FunctionReference constructor;
  static void Initialize(Napi::Env& env, Napi::Object& target);

  void Intersect(const Napi::CallbackInfo&);
  Napi::Value GetWidth(const Napi::CallbackInfo&);
  void SetWidth(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetHeight(const Napi::CallbackInfo&);
  void SetHeight(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetBottom(const Napi::CallbackInfo&);
  void SetBottom(const Napi::CallbackInfo&, const Napi::Value&);
  Napi::Value GetLeft(const Napi::CallbackInfo&);
  void SetLeft(const Napi::CallbackInfo&, const Napi::Value&);
  PoDoFo::PdfRect& GetRect() { return *rect; }

private:
  PoDoFo::PdfRect* rect;
};
}
#endif // NPDF_RECT_H
